@@ -360,6 +360,8 @@ private:								/*{{{*/
 
 // The 'extra-ansi' syntax is used to help with collisions. 
 GlobalError *_GetErrorObj();
-#define _error _GetErrorObj()
+static struct {
+	inline GlobalError* operator ->() { return _GetErrorObj(); }
+} _error APT_UNUSED APT_PKG_590("Consider rewriting this");
 
 #endif
