@@ -128,7 +128,7 @@ bool pkgCache::Header::CheckSizes(Header &Against) const
 pkgCache::pkgCache(MMap *Map, bool DoMap) : Map(*Map), VS(nullptr), d(NULL)
 {
    // call getArchitectures() with cached=false to ensure that the 
-   // architectures cache is re-evaulated. this is needed in cases
+   // architectures cache is re-evaluated. this is needed in cases
    // when the APT::Architecture field changes between two cache creations
    MultiArchEnabled = APT::Configuration::getArchitectures(false).size() > 1;
    if (DoMap == true)
@@ -274,6 +274,10 @@ uint32_t pkgCache::CacheHash()
    header.Dirty = false;
    header.CacheFileSize = 0;
 
+   adler = hash32(adler,
+		  reinterpret_cast<const unsigned char *>(PACKAGE_VERSION),
+		  APT_ARRAY_SIZE(PACKAGE_VERSION));
+
    adler = hash32(adler,
 		  reinterpret_cast<const unsigned char *>(&header),
 		  sizeof(header));
@@ -381,7 +385,7 @@ const char *pkgCache::Priority(unsigned char Prio)
 {
    const char *Mapping[] = {0,_("required"),_("important"),_("standard"),
                             _("optional"),_("extra")};
-   if (Prio < _count(Mapping))
+   if (Prio < APT_ARRAY_SIZE(Mapping))
       return Mapping[Prio];
    return 0;
 }
@@ -991,6 +995,23 @@ string pkgCache::PkgFileIterator::RelStr()				/*{{{*/
       Res = Res + (Res.empty() == true?"b=":",b=")  + Architecture();
    return Res;
 }
+									/*}}}*/
+// VerIterator::TranslatedDescriptionForLanguage - Return a DescIter for language/*{{{*/
+// ---------------------------------------------------------------------
+/* return a DescIter for the specified language
+ */
+pkgCache::DescIterator pkgCache::VerIterator::TranslatedDescriptionForLanguage(StringView lang) const
+{
+   for (pkgCache::DescIterator Desc = DescriptionList(); Desc.end() == false; ++Desc)
+      if (lang == Desc.LanguageCode())
+         return Desc;
+
+   if (lang == "en")
+      return TranslatedDescriptionForLanguage("");
+
+   return DescIterator();
+}
+
 									/*}}}*/
 // VerIterator::TranslatedDescription - Return the a DescIter for locale/*{{{*/
 // ---------------------------------------------------------------------
@@ -1003,30 +1024,15 @@ pkgCache::DescIterator pkgCache::VerIterator::TranslatedDescription() const
    for (std::vector<string>::const_iterator l = lang.begin();
 	l != lang.end(); ++l)
    {
-      pkgCache::DescIterator Desc = DescriptionList();
-      for (; Desc.end() == false; ++Desc)
-	 if (*l == Desc.LanguageCode())
-	    break;
-      if (Desc.end() == true)
-      {
-	 if (*l == "en")
-	 {
-	    Desc = DescriptionList();
-	    for (; Desc.end() == false; ++Desc)
-	       if (strcmp(Desc.LanguageCode(), "") == 0)
-		  break;
-	    if (Desc.end() == true)
-	       continue;
-	 }
-	 else
-	    continue;
-      }
-      return Desc;
+      pkgCache::DescIterator Desc = TranslatedDescriptionForLanguage(*l);
+      if (Desc.IsGood())
+         return Desc;
    }
-   for (pkgCache::DescIterator Desc = DescriptionList();
-	Desc.end() == false; ++Desc)
-      if (strcmp(Desc.LanguageCode(), "") == 0)
-	 return Desc;
+
+   pkgCache::DescIterator Desc = TranslatedDescriptionForLanguage("");
+   if (Desc.IsGood())
+      return Desc;
+
    return DescriptionList();
 }
 
