@@ -17,7 +17,6 @@
 #include <apt-pkg/hashsum_template.h>
 #include <apt-pkg/indexfile.h>
 #include <apt-pkg/macros.h>
-#include <apt-pkg/md5.h>
 #include <apt-pkg/metaindex.h>
 #include <apt-pkg/mmap.h>
 #include <apt-pkg/pkgcache.h>
@@ -558,10 +557,11 @@ bool pkgCacheGenerator::NewGroup(pkgCache::GrpIterator &Grp, StringView Name)
    if (unlikely(Group == 0))
       return false;
 
-   Grp = pkgCache::GrpIterator(Cache, Cache.GrpP + Group);
-   map_stringitem_t const idxName = StoreString(PKGNAME, Name);
+   map_stringitem_t const idxName = WriteStringInMap(Name);
    if (unlikely(idxName == 0))
       return false;
+
+   Grp = pkgCache::GrpIterator(Cache, Cache.GrpP + Group);
    Grp->Name = idxName;
 
    // Insert it into the hash table
@@ -1204,7 +1204,7 @@ bool pkgCacheListParser::NewProvidesAllArch(pkgCache::VerIterator &Ver, StringVi
    Dynamic<StringView> DynPackage(Package);
    Dynamic<StringView> DynVersion(Version);
 
-   if (Grp.end() == true)
+   if (Grp.end() == true || Grp->FirstPackage == 0)
       return NewProvides(Ver, Package, Cache.NativeArch(), Version, Flags);
    else
    {
@@ -1336,7 +1336,6 @@ map_stringitem_t pkgCacheGenerator::StoreString(enum StringType const type, cons
    auto strings = &strMixed;
    switch(type) {
       case MIXED: strings = &strMixed; break;
-      case PKGNAME: strings = &strPkgNames; break;
       case VERSIONNUMBER: strings = &strVersions; break;
       case SECTION: strings = &strSections; break;
       default: _error->Fatal("Unknown enum type used for string storage of '%.*s'", Size, S); return 0;
