@@ -19,7 +19,6 @@
 #define PKGLIB_PKGCACHEGEN_H
 
 #include <apt-pkg/macros.h>
-#include <apt-pkg/md5.h>
 #include <apt-pkg/mmap.h>
 #include <apt-pkg/pkgcache.h>
 
@@ -28,9 +27,7 @@
 #if __cplusplus >= 201103L
 #include <unordered_set>
 #endif
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
 #include <apt-pkg/string_view.h>
-#endif
 
 class FileFd;
 class pkgSourceList;
@@ -40,9 +37,7 @@ class pkgCacheListParser;
 
 class APT_HIDDEN pkgCacheGenerator					/*{{{*/
 {
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    APT_HIDDEN map_stringitem_t WriteStringInMap(APT::StringView String) { return WriteStringInMap(String.data(), String.size()); };
-#endif
    APT_HIDDEN map_stringitem_t WriteStringInMap(const char *String);
    APT_HIDDEN map_stringitem_t WriteStringInMap(const char *String, const unsigned long &Len);
    APT_HIDDEN map_pointer_t AllocateInMap(const unsigned long &size);
@@ -74,7 +69,6 @@ class APT_HIDDEN pkgCacheGenerator					/*{{{*/
    };
 
    std::unordered_set<string_pointer, hash> strMixed;
-   std::unordered_set<string_pointer, hash> strPkgNames;
    std::unordered_set<string_pointer, hash> strVersions;
    std::unordered_set<string_pointer, hash> strSections;
 #endif
@@ -112,14 +106,12 @@ class APT_HIDDEN pkgCacheGenerator					/*{{{*/
    std::string PkgFileName;
    pkgCache::PackageFile *CurrentFile;
 
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    bool NewGroup(pkgCache::GrpIterator &Grp, APT::StringView Name);
    bool NewPackage(pkgCache::PkgIterator &Pkg, APT::StringView Name, APT::StringView Arch);
    map_pointer_t NewVersion(pkgCache::VerIterator &Ver, APT::StringView const &VerStr,
 			    map_pointer_t const ParentPkg, unsigned short const Hash,
 			    map_pointer_t const Next);
    map_pointer_t NewDescription(pkgCache::DescIterator &Desc,const std::string &Lang, APT::StringView md5sum,map_stringitem_t const idxmd5str);
-#endif
    bool NewFileVer(pkgCache::VerIterator &Ver,ListParser &List);
    bool NewFileDesc(pkgCache::DescIterator &Desc,ListParser &List);
    bool NewDepends(pkgCache::PkgIterator &Pkg, pkgCache::VerIterator &Ver,
@@ -130,12 +122,10 @@ class APT_HIDDEN pkgCacheGenerator					/*{{{*/
 
    public:
 
-   enum StringType { MIXED, PKGNAME, VERSIONNUMBER, SECTION };
+   enum StringType { MIXED, VERSIONNUMBER, SECTION };
    map_stringitem_t StoreString(StringType const type, const char * S, unsigned int const Size);
 
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    inline map_stringitem_t StoreString(enum StringType const type, APT::StringView S) {return StoreString(type, S.data(),S.length());};
-#endif
 
    void DropProgress() {Progress = 0;};
    bool SelectFile(const std::string &File,pkgIndexFile const &Index, std::string const &Architecture, std::string const &Component, unsigned long Flags = 0);
@@ -163,19 +153,15 @@ class APT_HIDDEN pkgCacheGenerator					/*{{{*/
    void * const d;
    APT_HIDDEN bool MergeListGroup(ListParser &List, std::string const &GrpName);
    APT_HIDDEN bool MergeListPackage(ListParser &List, pkgCache::PkgIterator &Pkg);
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    APT_HIDDEN bool MergeListVersion(ListParser &List, pkgCache::PkgIterator &Pkg,
 			 APT::StringView const &Version, pkgCache::VerIterator* &OutVer);
-#endif
 
    APT_HIDDEN bool AddImplicitDepends(pkgCache::GrpIterator &G, pkgCache::PkgIterator &P,
 			   pkgCache::VerIterator &V);
    APT_HIDDEN bool AddImplicitDepends(pkgCache::VerIterator &V, pkgCache::PkgIterator &D);
 
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    APT_HIDDEN bool AddNewDescription(ListParser &List, pkgCache::VerIterator &Ver,
 	 std::string const &lang, APT::StringView CurMd5, map_stringitem_t &md5idx);
-#endif
 };
 									/*}}}*/
 // This is the abstract package list parser class.			/*{{{*/
@@ -191,15 +177,12 @@ class APT_HIDDEN pkgCacheListParser
    void * const d;
 
    protected:
-
+   inline bool NewGroup(pkgCache::GrpIterator &Grp, APT::StringView Name) { return Owner->NewGroup(Grp, Name); }
    inline map_stringitem_t StoreString(pkgCacheGenerator::StringType const type, const char *S,unsigned int Size) {return Owner->StoreString(type, S, Size);};
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    inline map_stringitem_t StoreString(pkgCacheGenerator::StringType const type, APT::StringView S) {return Owner->StoreString(type, S);};
    inline map_stringitem_t WriteString(APT::StringView S) {return Owner->WriteStringInMap(S.data(), S.size());};
-#endif
 
    inline map_stringitem_t WriteString(const char *S,unsigned int Size) {return Owner->WriteStringInMap(S,Size);};
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    bool NewDepends(pkgCache::VerIterator &Ver,APT::StringView Package, APT::StringView Arch,
 		   APT::StringView Version,uint8_t const Op,
 		   uint8_t const Type);
@@ -208,21 +191,16 @@ class APT_HIDDEN pkgCacheListParser
 		    uint8_t const Flags);
    bool NewProvidesAllArch(pkgCache::VerIterator &Ver, APT::StringView Package,
 			   APT::StringView Version, uint8_t const Flags);
-#endif
    public:
    
    // These all operate against the current section
    virtual std::string Package() = 0;
    virtual bool ArchitectureAll() = 0;
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    virtual APT::StringView Architecture() = 0;
    virtual APT::StringView Version() = 0;
-#endif
    virtual bool NewVersion(pkgCache::VerIterator &Ver) = 0;
    virtual std::vector<std::string> AvailableDescriptionLanguages() = 0;
-#ifdef APT_PKG_EXPOSE_STRING_VIEW
    virtual APT::StringView Description_md5() = 0;
-#endif
    virtual unsigned short VersionHash() = 0;
    /** compare currently parsed version with given version
     *
@@ -245,8 +223,4 @@ class APT_HIDDEN pkgCacheListParser
 };
 									/*}}}*/
 
-APT_DEPRECATED_MSG("Use pkgCacheGenerator::MakeStatusCache instead") bool pkgMakeStatusCache(pkgSourceList &List,OpProgress &Progress,
-			MMap **OutMap = 0,bool AllowMem = false);
-APT_DEPRECATED_MSG("Use pkgCacheGenerator::MakeOnlyStatusCache instead") bool pkgMakeOnlyStatusCache(OpProgress &Progress,DynamicMMap **OutMap);
-
 #endif
