@@ -76,6 +76,8 @@ class pkgPolicy : public pkgDepCache::Policy
    virtual signed short GetPriority(pkgCache::VerIterator const &Ver, bool ConsiderFiles = true) APT_OVERRIDE;
    virtual signed short GetPriority(pkgCache::PkgFileIterator const &File) APT_OVERRIDE;
 
+   void SetPriority(pkgCache::VerIterator const &Ver, signed short Priority);
+   void SetPriority(pkgCache::PkgFileIterator const &File, signed short Priority);
    bool InitDefaults();
    
    explicit pkgPolicy(pkgCache *Owner);
