@@ -38,9 +38,6 @@
 
 #include <string>
 
-#ifndef APT_8_CLEANER_HEADERS
-using std::string;
-#endif
 
 class pkgVersionMatch
 {
